# GoBright Interact Serial Flasher Helper
Copyright © GoBright

## Introduction

Welcome to the GoBright Interact Serial Flasher Helper! This tool is designed to assist you in flashing firmware to your GoBright Interact devices. This script is intended to be used by technical users under the guidance of GoBright support. Please handle this tool with care, as improper use may result in unintended consequences.

**Disclaimer:** This script and any accompanying firmware files are the exclusive property of GoBright. Unauthorized use, reproduction, or distribution of this script or firmware files is strictly prohibited.

**Note:** This script comes bundled with and uses `esptool`, which is licensed under the GNU General Public License v2. For more details on this license, visit: [GNU GPL v2 License](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html). The `esptool.exe` is the property of Espressif Systems.

## Table of Contents

1. [Prerequisites](#prerequisites)
2. [File Structure](#file-structure)
3. [Usage Instructions](#usage-instructions)
4. [Options and Modes](#options-and-modes)
5. [Disclaimers and Legal Information](#disclaimers-and-legal-information)
6. [Revision History](#revision-history)

## Prerequisites

Before using this script, ensure you have the following:

- A Windows PC with PowerShell installed.
- The GoBright Interact Serial Flasher Helper script bundle.
- The necessary firmware and system files provided by GoBright.
- A powered GoBright Interact device connected to your PC via it's USB-C port.

## File Structure

Your file structure should look like this:

```
FlashHelperScriptBundle
├── flash-interact-fw.ps1
├── InteractFirmwareFiles
│   ├── Place Interact Firmware BIN files here.txt
│   ├── interact-1.6.1-master-7edb093-0140.bin (for example, not included)
│   └── interact-1.6.0-master-c3d3d7d-0139.bin (for example, not included)
├── InteractFlashTools
│   ├── esptool.exe
│   └── LICENSE (this license is for esptool.exe only)
└── README.md (this file)
```

## Usage Instructions

1. **Place Firmware and System Files:**
   - Place the firmware `.bin` files in the `InteractFirmwareFiles` folder.
		- If no firmware file was provided you can download latest firmware file [>here<](https://install.gobright.cloud/interact/?mode=download&version=latest)
		- Older versions can be found [>here<](https://install.gobright.cloud/interact/)

2. **Run the Script:**
   - Open PowerShell.
   - Navigate to the directory where the script is located.
   - Execute the script by typing `.\flash-interact-fw.ps1` and pressing `Enter`.
   - If windows security asks if you want to trust/run this script select yes/run

3. **Follow the On-Screen Instructions:**
   - The script will guide you through selecting the firmware file, setting options, and flashing the device.

## Options and Modes

### Firmware File Selection

- If multiple firmware files are detected, you will be prompted to select one.
- If only one firmware file is detected, it will be selected automatically.

### Port Detection Method

- **Autodetect (Experimental):** The script will attempt to automatically detect the ESP device connected to your PC. If a port is determined to not be an Interact it will be added to a local blacklist meaning it will be skipped on subsequent runs. This list is cleared if you exit the script.
- **Manual Select:** You will be prompted to manually select the serial port from a list of options.

### Clear Blacklist

- Clears the blacklist of serial ports that were previously determined not to be ESP devices. This option is only available in Autodetect mode.

## Disclaimers and Legal Information

- **Copyright:** © GoBright. This script and any accompanying firmware files are the exclusive property of GoBright. Unauthorized use, reproduction, or distribution of this script or firmware files is strictly prohibited.
- **Usage:** This tool is intended for use only under the guidance of GoBright support.
- **Third-Party License:** This script uses `esptool`, which is licensed under the GNU General Public License v2. For more details on this license, visit: [GNU GPL v2 License](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html). `esptool.exe` is the property of Espressif Systems.

## Revision History

| Date       | Version | Description                        | Author |
|------------|---------|------------------------------------|--------|
| 28/03/2024 |    v1.0 | Initial Proof of Concept           |   W.H. |
| 17/06/2024 |    v1.1 | Bundle esptool.exe, port detection |   R.B. |
| 17/06/2024 |    v1.2 | Handle edge cases and update TUI   |   R.B. |
| 18/06/2024 |    v1.3 | Cleanup script, add documentation  |   R.B. |
| 19/06/2024 |    v1.4 | Rework com port selection          |   R.B. |
| 19/06/2024 |    v1.5 | Cleanup TUI and Documentation      |   R.B. |

*Last updated on 19/06/2024*